@@ -43,7 +43,11 @@ TipQalc::TipQalc(QWidget *parent) :
     connect(ui->actionAbout, SIGNAL(triggered()),
             this, SLOT(showAboutDialog()));
 
-    QSettings settings("SeviSoft", "TipQalc");
+    QCoreApplication::setOrganizationName("SeviSoft");
+    QCoreApplication::setOrganizationDomain("sevisoft.com");
+    QCoreApplication::setApplicationName("TipQalc");
+
+    QSettings settings;
     //settings.clear();
 
     QString taxPercent = settings.value("taxPercent").toString();
@@ -61,10 +65,9 @@ TipQalc::TipQalc(QWidget *parent) :
 
 TipQalc::~TipQalc()
 {
-    QSettings settings("SeviSoft", "TipQalc");
+    QSettings settings;
     settings.setValue("taxPercent", ui->taxLine->text());
     settings.setValue("tipPercent", ui->tipLine->text());
-
     delete ui;
 }
 
@@ -167,7 +170,7 @@ void TipQalc::calculateTip()
     float tipPercent = ui->tipLine->text().toFloat();
     float bill = ui->billLine->text().toFloat();
 
-    QSettings settings("SeviSoft", "TipQalc");
+    QSettings settings;
     bool useTax = settings.value("subtractTaxFromTotal").toBool();
 
     float tip;
